# museum ghosts, obviously [![Build Status](https://travis-ci.org/pgdr/museumghosts.svg?branch=master)](https://travis-ci.org/pgdr/museumghosts)

a game of life and death

look: 👻

![screenshot](https://raw.githubusercontent.com/pgdr/museumghosts/master/ghost-screenshot.png)
